package com.ruoyi.ss.device.service;

import com.ruoyi.common.utils.CollectionUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.ss.device.domain.SmDevice;
import com.ruoyi.ss.device.domain.vo.SmDeviceVo;
import com.ruoyi.ss.store.domain.StoreQuery;
import com.ruoyi.ss.store.domain.StoreVo;
import com.ruoyi.ss.store.service.IStoreService;
import com.ruoyi.ss.deviceTenant.domain.SmDeviceTenant;
import com.ruoyi.ss.deviceTenant.service.ISmDeviceTenantService;
import com.ruoyi.ss.suit.domain.SuitQuery;
import com.ruoyi.ss.suit.domain.SuitVo;
import com.ruoyi.ss.suit.service.ISuitService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @author wjh
 * 2024/4/13
 */
@Service
public class DeviceAssemblerImpl implements DeviceAssembler {

    @Autowired
    private ISmDeviceTenantService deviceTenantService;

    @Autowired
    private IStoreService smDeviceGroupService;

    @Autowired
    private ISuitService suitService;

    @Autowired
    private IStoreService storeService;

    @Override
    public void assembleTenant(List<SmDeviceVo> list) {
        if (CollectionUtils.isEmpty(list)) {
            return;
        }
        Map<Long, List<SmDeviceTenant>> tenantGroup = deviceTenantService.selectGroupByDeviceIds(list.stream().map(SmDeviceVo::getDeviceId).collect(Collectors.toList()));

        for (SmDeviceVo device : list) {
            List<SmDeviceTenant> tenants = tenantGroup.get(device.getDeviceId());
            if (CollectionUtils.isEmpty(tenants)) {
                continue;
            }
            device.setTenantIds(tenants.stream().map(SmDeviceTenant::getTenantId).collect(Collectors.toList()));
        }
    }

    /**
     * 拼接套餐列表
     *
     * @param list
     */
    @Override
    public void assembleSuitList(List<SmDeviceVo> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        SuitQuery query = new SuitQuery();
        query.setDeviceIds(list.stream().map(SmDeviceVo::getDeviceId).collect(Collectors.toList()));
        Map<Long, List<SuitVo>> groups = suitService.selectGroup(query, SuitVo::getDeviceId);

        for (SmDeviceVo device : list) {
            device.setSuitList(groups.get(device.getDeviceId()));
        }
    }

    /**
     * 拼接店铺营业时间
     *
     * @param list
     */
    @Override
    public void assembleBusinessTime(List<SmDeviceVo> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        StoreQuery query = new StoreQuery();
        query.setStoreIds(list.stream().map(SmDeviceVo::getStoreId).filter(Objects::nonNull).distinct().collect(Collectors.toList()));
        Map<Long, StoreVo> map = storeService.selectMap(query, StoreVo::getStoreId);

        for (SmDeviceVo device : list) {
            StoreVo store = device.getStoreId() == null ? null : map.get(device.getStoreId());
            if (store != null) {
                device.setStoreBusinessTimeStart(store.getBusinessTimeStart());
                device.setStoreBusinessTimeEnd(store.getBusinessTimeEnd());
            }
        }

    }
}
